﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;

namespace CompositeChartWLegend90867
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            this.Load += new EventHandler(Form1_Load);
        }

        void Form1_Load(object sender, EventArgs e)
        {
            //Set the chart type to reflect that of the composite chart
            ultraChart1.ChartType = ChartType.Composite;

            //Create a new chart area
            ChartArea chartArea1 = new ChartArea();
            //Add this chart area to the CompositeChart's ChartArea collection
            ultraChart1.CompositeChart.ChartAreas.Add(chartArea1);

            //Create an axis object
            AxisItem xAxisLine = new AxisItem();
            //Set the axis for this object
            xAxisLine.axisNumber = AxisNumber.X_Axis;
            //Give data type for the AxisItem
            xAxisLine.DataType = AxisDataType.String;
            //Provide the desired LabelAxisType; for the presentation of a composite line chart, Continuous Data will be the most effective style of presentation
            xAxisLine.SetLabelAxisType = SetLabelAxisType.ContinuousData;
            //Set the desired label format for the axis
            xAxisLine.Labels.ItemFormat = AxisItemLabelFormat.ItemLabel;
            //Set the desired orientation for the axis labels
            xAxisLine.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            //Add the axes to the chart area
            chartArea1.Axes.Add(xAxisLine);

            AxisItem yAxisLine = new AxisItem();
            yAxisLine.axisNumber = AxisNumber.Y_Axis;
            //Set the desired dataType for the Y axis, since this is the axis that we will be plotting the actual point value, it will need to be numeric
            yAxisLine.DataType = AxisDataType.Numeric;
            //Set the TickmarkStyle for the axis
            yAxisLine.TickmarkStyle = AxisTickStyle.Smart;
            //Set the desired Y axis label format
            yAxisLine.Labels.ItemFormat = AxisItemLabelFormat.DataValue;
            //Add the yAxisLine to the Axes collection of the chartArea
            chartArea1.Axes.Add(yAxisLine);

            //Create a new ChartAreaAppearance object
            ChartLayerAppearance lineLayer = new ChartLayerAppearance();
            //Assign the desired chart type
            lineLayer.ChartType = ChartType.LineChart;

            //Assign the desired axis object for the lineLayer's axes
            lineLayer.AxisX = xAxisLine;
            lineLayer.AxisY = yAxisLine;

            //Set the desired axis line thickness
            lineLayer.AxisY.LineThickness = 1;
            //Allocate the ChartArea for the lineLayer, in this case we are using the earlier created chartArea1 object
            lineLayer.ChartArea = chartArea1;

            //Populate the chartLayer with some sample data
            lineLayer.Series.Add(GetSeries1());
            lineLayer.Series.Add(GetSeries2());
            lineLayer.Series.Add(GetSeries3());

            //Add the lineLayer object to the ChartLayers collection of the CompositeChart
            ultraChart1.CompositeChart.ChartLayers.Add(lineLayer);

            //Create a rectangle object that will be used to modify the chart area's position and location
            Rectangle rect = new Rectangle();
            //Set the rect dimensions to that of the chart area
            rect = lineLayer.ChartArea.Bounds;
            //Set the desired X position of the chart area's upper left rect corner
            rect.X = 0;
            //Set the desired Y position of the chart area's upper left rect corner
            rect.Y = 20;
            //Set the desired size of the chart area
            rect.Size = new System.Drawing.Size(760, 520);
            //Set the chart area's bounds to that of the rect
            lineLayer.ChartArea.Bounds = rect;
            //Set the desired thickness to the chart area's border, (in this case, the border has been omitted for asthetics)
            lineLayer.ChartArea.Border.Thickness = 0;

            //Create a CompositeChart legend object
            CompositeLegend lineLegend1 = new CompositeLegend();

            //Set the position and size of the legend within the chart area
            lineLegend1.Bounds = new Rectangle(2, 88, 9, 9);

            //Misc appearance properties for the chart legend
            lineLegend1.BoundsMeasureType = MeasureType.Percentage;
            lineLegend1.PE.ElementType = PaintElementType.SolidFill;
            lineLegend1.PE.Fill = Color.Cyan;
            lineLegend1.Border.CornerRadius = 2;
            lineLegend1.Border.Thickness = 1;
            lineLegend1.PE.FillStopColor = Color.Transparent;

            //Add the lineLayer to the chart legend, (all discrete datasets will be displayed with their own legend entry)
            lineLegend1.ChartLayers.Add(lineLayer);
            //Add the legend to the CompositeChart's legend collection
            this.ultraChart1.CompositeChart.Legends.Add(lineLegend1);
        }

        private static NumericSeries GetSeries1()
        {
            NumericSeries seriesLine = new NumericSeries();
            Random r = new Random(1);

            //Set the desired label for this NumericSeries; this label will be displayed within the chart's legend
            seriesLine.Label = "Series A";

            for (int i = 0; i < 9; i++)
            {
                //Create a single point on the line chart's surface, (this will be iterated several times to create a series of connected points).
                seriesLine.Points.Add(new NumericDataPoint(r.Next(0, 10), "point:" + i.ToString(), false));
            }

            return seriesLine;
        }

        private static NumericSeries GetSeries2()
        {
            NumericSeries seriesLine = new NumericSeries();
            Random r = new Random(5);

            seriesLine.Label = "Series B";

            for (int i = 0; i < 9; i++)
            {
                seriesLine.Points.Add(new NumericDataPoint(r.Next(0, 10), "point:" + i.ToString(), false));
            }

            return seriesLine;
        }

        private static NumericSeries GetSeries3()
        {
            NumericSeries seriesLine = new NumericSeries();
            Random r = new Random(9);

            seriesLine.Label = "Series C";

            for (int i = 0; i < 9; i++)
            {
                seriesLine.Points.Add(new NumericDataPoint(r.Next(0, 10), "point:" + i.ToString(), false));
            }
            return seriesLine;
        }
    }
}
